@@ -24,15 +24,16 @@ __author__ = "Cyril Jaquier"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier"
 __license__ = "GPL"
 
-import logging, re, glob, os.path
+import re, glob, os.path
 import json
 
-from .configreader import ConfigReader
+from .configreader import ConfigReaderUnshared, ConfigReader
 from .filterreader import FilterReader
 from .actionreader import ActionReader
+from ..helpers import getLogger
 
 # Gets the instance of the logger.
-logSys = logging.getLogger(__name__)
+logSys = getLogger(__name__)
 
 class JailReader(ConfigReader):
 	
@@ -68,7 +69,8 @@ class JailReader(ConfigReader):
 		return out
 	
 	def isEnabled(self):
-		return self.__force_enable or ( self.__opts and self.__opts["enabled"] )
+		return self.__force_enable or (
+			self.__opts and self.__opts.get("enabled", False))
 
 	@staticmethod
 	def _glob(path):
@@ -85,14 +87,14 @@ class JailReader(ConfigReader):
 		return pathList
 
 	def getOptions(self):
-		opts = [["bool", "enabled", "false"],
-				["string", "logpath", "/var/log/messages"],
-				["string", "logencoding", "auto"],
+		opts = [["bool", "enabled", False],
+				["string", "logpath", None],
+				["string", "logencoding", None],
 				["string", "backend", "auto"],
-				["int", "maxretry", 3],
-				["int", "findtime", 600],
-				["int", "bantime", 600],
-				["string", "usedns", "warn"],
+				["int", "maxretry", None],
+				["int", "findtime", None],
+				["int", "bantime", None],
+				["string", "usedns", None],
 				["string", "failregex", None],
 				["string", "ignoreregex", None],
 				["string", "ignorecommand", None],
@@ -109,7 +111,7 @@ class JailReader(ConfigReader):
 				filterName, filterOpt = JailReader.extractOptions(
 					self.__opts["filter"])
 				self.__filter = FilterReader(
-					filterName, self.__name, filterOpt, basedir=self.getBaseDir())
+					filterName, self.__name, filterOpt, share_config=self.share_config, basedir=self.getBaseDir())
 				ret = self.__filter.read()
 				if ret:
 					self.__filter.getOptions(self.__opts)
@@ -139,7 +141,7 @@ class JailReader(ConfigReader):
 					else:
 						action = ActionReader(
 							actName, self.__name, actOpt,
-							basedir=self.getBaseDir())
+							share_config=self.share_config, basedir=self.getBaseDir())
 						ret = action.read()
 						if ret:
 							action.getOptions(self.__opts)
@@ -211,18 +213,18 @@ class JailReader(ConfigReader):
 		if self.__filter:
 			stream.extend(self.__filter.convert())
 		for action in self.__actions:
-			if isinstance(action, ConfigReader):
+			if isinstance(action, (ConfigReaderUnshared, ConfigReader)):
 				stream.extend(action.convert())
 			else:
 				stream.append(action)
 		stream.insert(0, ["add", self.__name, backend])
 		return stream
 	
-	#@staticmethod
+	@staticmethod
 	def extractOptions(option):
 		match = JailReader.optionCRE.match(option)
 		if not match:
-			# TODO propper error handling
+			# TODO proper error handling
 			return None, None
 		option_name, optstr = match.groups()
 		option_opts = dict()
@@ -233,4 +235,3 @@ class JailReader(ConfigReader):
 					val for val in optmatch.group(2,3,4) if val is not None][0]
 				option_opts[opt.strip()] = value.strip()
 		return option_name, option_opts
-	extractOptions = staticmethod(extractOptions)
