@@ -24,16 +24,13 @@ __author__ = "Cyril Jaquier"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier"
 __license__ = "GPL"
 
-import re, time, calendar
-import logging
+import re
 from abc import abstractmethod
-from datetime import datetime
-from datetime import timedelta
 
-from .mytime import MyTime
 from .strptime import reGroupDictStrptime, timeRE
+from ..helpers import getLogger
 
-logSys = logging.getLogger(__name__)
+logSys = getLogger(__name__)
 
 
 class DateTemplate(object):
@@ -76,7 +73,7 @@ class DateTemplate(object):
 			The regex the template will use for searching for a date.
 		wordBegin : bool
 			Defines whether the regex should be modified to search at
-			begining of a word, by adding "\\b" to start of regex.
+			beginning of a word, by adding "\\b" to start of regex.
 			Default True.
 
 		Raises
