@@ -21,9 +21,9 @@ __author__ = "Cyril Jaquier, Yaroslav Halchenko"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier, 2011-2013 Yaroslav Halchenko"
 __license__ = "GPL"
 
-import os, glob, shutil, sys, tempfile, unittest
-
-from ..client.configreader import ConfigReader
+import os, glob, shutil, tempfile, unittest, re, logging
+from ..client.configreader import ConfigReaderUnshared
+from ..client import configparserinc
 from ..client.jailreader import JailReader
 from ..client.filterreader import FilterReader
 from ..client.jailsreader import JailsReader
@@ -32,8 +32,10 @@ from ..client.configurator import Configurator
 from .utils import LogCaptureTestCase
 
 TEST_FILES_DIR = os.path.join(os.path.dirname(__file__), "files")
+
+from .utils import CONFIG_DIR
+
 STOCK = os.path.exists(os.path.join('config','fail2ban.conf'))
-CONFIG_DIR='config' if STOCK else '/etc/fail2ban'
 
 IMPERFECT_CONFIG = os.path.join(os.path.dirname(__file__), 'config')
 
@@ -42,7 +44,7 @@ class ConfigReaderTest(unittest.TestCase):
 	def setUp(self):
 		"""Call before every test case."""
 		self.d = tempfile.mkdtemp(prefix="f2b-temp")
-		self.c = ConfigReader(basedir=self.d)
+		self.c = ConfigReaderUnshared(basedir=self.d)
 
 	def tearDown(self):
 		"""Call after every test case."""
@@ -326,13 +328,86 @@ class FilterReaderTest(unittest.TestCase):
 		self.assertEqual(sorted(c), sorted(output))
 
 	def testFilterReaderSubstitionFail(self):
-		output = [['set', 'jailname', 'addfailregex', 'to=sour@example.com fromip=<IP>']]
 		filterReader = FilterReader('substition', "jailname", {'honeypot': '<sweet>', 'sweet': '<honeypot>'})
 		filterReader.setBaseDir(TEST_FILES_DIR)
 		filterReader.read()
 		filterReader.getOptions(None)
 		self.assertRaises(ValueError, FilterReader.convert, filterReader)
 
+	def testFilterReaderExplicit(self):
+		# read explicit uses absolute path:
+		path_ = os.path.abspath(os.path.join(TEST_FILES_DIR, "filter.d"))
+		filterReader = FilterReader(os.path.join(path_, "testcase01.conf"), "testcase01", {})
+		self.assertEqual(filterReader.readexplicit(), 
+			[os.path.join(path_, "testcase-common.conf"), os.path.join(path_, "testcase01.conf")]
+		)
+		try:
+			filterReader.getOptions(None)
+			# from included common
+			filterReader.get('Definition', '__prefix_line')
+			# from testcase01
+			filterReader.get('Definition', 'failregex')
+			filterReader.get('Definition', 'ignoreregex')
+		except Exception, e: # pragma: no cover - failed if reachable
+			self.fail('unexpected options after readexplicit: %s' % (e))
+
+class JailsReaderTestCache(LogCaptureTestCase):
+
+	def _readWholeConf(self, basedir, force_enable=False, share_config=None):
+		# read whole configuration like a file2ban-client ...
+		configurator = Configurator(force_enable=force_enable, share_config=share_config)
+		configurator.setBaseDir(basedir)
+		configurator.readEarly()
+		configurator.getEarlyOptions()
+		configurator.readAll()
+		# from here we test a cache with all includes / before / after :
+		self.assertTrue(configurator.getOptions(None))
+
+	def _getLoggedReadCount(self, filematch):
+		cnt = 0
+		for s in self.getLog().rsplit('\n'):
+			if re.match(r"^\s*Reading files?: .*/"+filematch, s):
+				cnt += 1
+		return cnt
+
+	def testTestJailConfCache(self):
+		saved_ll = configparserinc.logLevel
+		configparserinc.logLevel = logging.DEBUG
+		basedir = tempfile.mkdtemp("fail2ban_conf")
+		try:
+			shutil.rmtree(basedir)
+			shutil.copytree(CONFIG_DIR, basedir)
+			shutil.copy(CONFIG_DIR + '/jail.conf', basedir + '/jail.local')
+			shutil.copy(CONFIG_DIR + '/fail2ban.conf', basedir + '/fail2ban.local')
+
+			# common sharing handle for this test:
+			share_cfg = dict()
+
+			# read whole configuration like a file2ban-client ...
+			self._readWholeConf(basedir, share_config=share_cfg)
+			# how many times jail.local was read:
+			cnt = self._getLoggedReadCount('jail.local')
+			# if cnt > 1:
+			# 	self.printLog()
+			self.assertTrue(cnt == 1, "Unexpected count by reading of jail files, cnt = %s" % cnt)
+
+			# read whole configuration like a file2ban-client, again ...
+			# but this time force enable all jails, to check filter and action cached also:
+			self._readWholeConf(basedir, force_enable=True, share_config=share_cfg)
+			cnt = self._getLoggedReadCount(r'jail\.local')
+			# still one (no more reads):
+			self.assertTrue(cnt == 1, "Unexpected count by second reading of jail files, cnt = %s" % cnt)
+
+			# same with filter:
+			cnt = self._getLoggedReadCount(r'filter\.d/common\.conf')
+			self.assertTrue(cnt == 1, "Unexpected count by reading of filter files, cnt = %s" % cnt)
+			# same with action:
+			cnt = self._getLoggedReadCount(r'action\.d/iptables-common\.conf')
+			self.assertTrue(cnt == 1, "Unexpected count by reading of action files, cnt = %s" % cnt)
+		finally:
+			shutil.rmtree(basedir)
+			configparserinc.logLevel = saved_ll
+
 
 class JailsReaderTest(LogCaptureTestCase):
 
@@ -350,31 +425,9 @@ class JailsReaderTest(LogCaptureTestCase):
 		self.maxDiff = None
 		self.assertEqual(sorted(comm_commands),
 			sorted([['add', 'emptyaction', 'auto'],
-			 ['set', 'emptyaction', 'usedns', 'warn'],
-			 ['set', 'emptyaction', 'maxretry', 3],
-			 ['set', 'emptyaction', 'findtime', 600],
-			 ['set', 'emptyaction', 'logencoding', 'auto'],
-			 ['set', 'emptyaction', 'bantime', 600],
-			 ['add', 'special', 'auto'],
-			 ['set', 'special', 'usedns', 'warn'],
-			 ['set', 'special', 'maxretry', 3],
-			 ['set', 'special', 'addfailregex', '<IP>'],
-			 ['set', 'special', 'findtime', 600],
-			 ['set', 'special', 'logencoding', 'auto'],
-			 ['set', 'special', 'bantime', 600],
 			 ['add', 'missinglogfiles', 'auto'],
-			 ['set', 'missinglogfiles', 'usedns', 'warn'],
-			 ['set', 'missinglogfiles', 'maxretry', 3],
-			 ['set', 'missinglogfiles', 'findtime', 600],
-			 ['set', 'missinglogfiles', 'logencoding', 'auto'],
-			 ['set', 'missinglogfiles', 'bantime', 600],
 			 ['set', 'missinglogfiles', 'addfailregex', '<IP>'],
 			 ['add', 'brokenaction', 'auto'],
-			 ['set', 'brokenaction', 'usedns', 'warn'],
-			 ['set', 'brokenaction', 'maxretry', 3],
-			 ['set', 'brokenaction', 'findtime', 600],
-			 ['set', 'brokenaction', 'logencoding', 'auto'],
-			 ['set', 'brokenaction', 'bantime', 600],
 			 ['set', 'brokenaction', 'addfailregex', '<IP>'],
 			 ['set', 'brokenaction', 'addaction', 'brokenaction'],
 			 ['set',
@@ -383,23 +436,9 @@ class JailsReaderTest(LogCaptureTestCase):
 			  'brokenaction',
 			  'actionban',
 			  'hit with big stick <ip>'],
-			 ['set', 'brokenaction', 'action', 'brokenaction',
-				'actionstop', ''],
-			 ['set', 'brokenaction', 'action', 'brokenaction',
-				'actionstart', ''],
-			 ['set', 'brokenaction', 'action', 'brokenaction',
-				'actionunban', ''],
-			 ['set', 'brokenaction', 'action', 'brokenaction',
-				'actioncheck', ''],
 			 ['add', 'parse_to_end_of_jail.conf', 'auto'],
-			 ['set', 'parse_to_end_of_jail.conf', 'usedns', 'warn'],
-			 ['set', 'parse_to_end_of_jail.conf', 'maxretry', 3],
-			 ['set', 'parse_to_end_of_jail.conf', 'findtime', 600],
-			 ['set', 'parse_to_end_of_jail.conf', 'logencoding', 'auto'],
-			 ['set', 'parse_to_end_of_jail.conf', 'bantime', 600],
 			 ['set', 'parse_to_end_of_jail.conf', 'addfailregex', '<IP>'],
 			 ['start', 'emptyaction'],
-			 ['start', 'special'],
 			 ['start', 'missinglogfiles'],
 			 ['start', 'brokenaction'],
 			 ['start', 'parse_to_end_of_jail.conf'],]))
@@ -573,6 +612,7 @@ class JailsReaderTest(LogCaptureTestCase):
 		jailfd = open(os.path.join(basedir, "jail.conf"), 'w')
 		jailfd.write("""
 [testjail1]
+enabled = true
 action = testaction1[actname=test1]
          testaction1[actname=test2]
          testaction.py
